## 采集工具

![base.png](base.png)

### 使用方法

- 运行`python video.py`

1. 显示：会显示全部相机图像
2. 选择保存路径：选择视频或者图像的保存路径
3. 勾选需要保存的相机窗口
4. 填写采集信息
5. 扫描配置，确认需要保存的窗口以及信息
6. 开始录制视频或者拍摄单帧图像

### 其他

#### 相机遮挡方案

- 默认代码中，勾选use model会执行相机遮挡检测（IR）
    - 如果被遮挡：画面周围显示红色
    - 如果没有被遮挡：画面周围显示绿色